Environment

Enum Environment 

pub enum Environment {
Show 22 variants Unknown = 0, GNU = 1, GNUABIN32 = 2, GNUABI64 = 3, GNUEABI = 4, GNUEABIHF = 5, GNUX32 = 6, CODE16 = 7, EABI = 8, EABIHF = 9, Android = 10, Musl = 11, MuslEABI = 12, MuslEABIHF = 13, MSVC = 15, Itanium = 16, Cygnus = 17, CoreCLR = 18, Simulator = 19, MacABI = 20, Standard = 23, Kernel = 24,
}
The Environment field of target tuples

Variants



Unknown = 0



GNU = 1



GNUABIN32 = 2



GNUABI64 = 3



GNUEABI = 4



GNUEABIHF = 5



GNUX32 = 6



CODE16 = 7



EABI = 8



EABIHF = 9



Android = 10



Musl = 11



MuslEABI = 12



MuslEABIHF = 13



MSVC = 15



Itanium = 16



Cygnus = 17



CoreCLR = 18



Simulator = 19



MacABI = 20



Standard = 23



Kernel = 24

Implementations

Source

impl Environment

pub fn parse(s: &str) -> Environment

Parses the Environment name in a “lossy” manner This is equivalent to Self::from_str, except that Environment::Unknown is returned, instead of an error, on an unknown OS Field

pub fn canonical_name(&self) -> &'static str

Returns the canonical name of the environment The canonical name, when passed into Self::parse will yield an equivalent value, Formatting an Environment yields this string