ObjectFormat

Enum ObjectFormat 

#[non_exhaustive]
pub enum ObjectFormat { Unknown = 0, XCoff = 1, Coff = 2, Elf = 3, Goff = 4, MachO = 5, Wasm = 6, Xo65 = 7, O65 = 8, WlaObj = 9, }
The object format used by a target

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown = 0



XCoff = 1



Coff = 2



Elf = 3



Goff = 4



MachO = 5



Wasm = 6



Xo65 = 7



O65 = 8



WlaObj = 9

Implementations

Source

impl ObjectFormat

pub fn parse(s: &str) -> ObjectFormat

Parses the ObjectFormat name in a “lossy” manner, from the end of the Environment field This is equivalent to Self::from_str, except that ObjectFormat::Unknown is returned, instead of an error, on an unknown OS Field

pub fn canonical_name(&self) -> &'static str

Returns the canonical name of the object format The canonical name, when passed into Self::parse will yield an equivalent value, Formatting an ObjectFormat yields this string